@@ -3,7 +3,7 @@ BEGIN {
   $Reply::App::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::App::VERSION = '0.13';
+  $Reply::App::VERSION = '0.14';
 }
 use strict;
 use warnings;
@@ -23,11 +23,18 @@ sub run {
     my $self = shift;
     my @argv = @_;
 
+    Getopt::Long::Configure("gnu_getopt");
+
     my $cfgfile = '.replyrc';
     my $exitcode;
+    my @modules;
     my $parsed = GetOptionsFromArray(
         \@argv,
         'cfg:s'   => \$cfgfile,
+        'l|lib'   => sub { push @INC, 'lib' },
+        'b|blib'  => sub { push @INC, 'blib/lib', 'blib/arch' },
+        'I:s@'    => sub { push @INC, $_[1] },
+        'M:s@'    => \@modules,
         'version' => sub { $exitcode = 0; version() },
         'help'    => sub { $exitcode = 0; usage() },
     );
@@ -60,7 +67,9 @@ sub run {
         }
     }
 
-    Reply->new(%args)->run;
+    my $reply = Reply->new(%args);
+    $reply->step("use $_") for @modules;
+    $reply->run;
 
     return 0;
 }
@@ -68,7 +77,7 @@ sub run {
 
 sub usage {
     my $fh = $_[0] ? *STDERR : *STDOUT;
-    print $fh "    reply [--version] [--help] [--cfg file]\n";
+    print $fh "    reply [-lb] [-I dir] [-M mod] [--version] [--help] [--cfg file]\n";
 }
 
 
@@ -87,7 +96,7 @@ Reply::App - command line app runner for Reply
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
